[GitHub Pages](https://jameskabbes.github.io/the_garden/)

# the_garden
A build of commonly-used open-source tools

# Project Description
A collection of Python packages used collectively to ease the pains of team development.

# Installing
To install for the first time:
```
pip install kabbes_the_garden
```

To upgrade an installation
```
pip install kabbes_the_garden --upgrade
```

# Author(s)
James Kabbes